ams.core.service.LoadScale
==========================

.. currentmodule:: ams.core.service

.. autoclass:: LoadScale

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~LoadScale.assign_memory
       
       
          ~LoadScale.evaluate
       
       
          ~LoadScale.get_names
       
       
          ~LoadScale.parse
       
       
          ~LoadScale.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~LoadScale.class_name
      ~LoadScale.n
      ~LoadScale.shape
      ~LoadScale.size
      ~LoadScale.v
   
   